#!/usr/bin/python3
# -*- coding: utf-8 -*-
import sqlite3
import os
import apt
from model.globals import Globals
from PyQt5.QtCore import QProcess,QDir,QFileInfo,QFile,QIODevice
from PyQt5.QtDBus import *

import time
import threading
import datetime
import configparser
import psutil
import sys

lock = threading.Lock()

class DbService:
    cpu = ""
    arch = ""
    def __init__(self):

        Globals.logInfo.logger.info("Start initializing data")
        self.updatecount = 0
        self.aptCache = None
        cacheFile = os.path.join(Globals.installPackagePath, "uksc.db")      #安装路径的数据库
        srcFile = os.path.join(Globals.userCacheUkscDir, "uksc.db")            #从服务端获取数据更新到该数据库
        procFile = os.path.join(Globals.userCacheUkscDir, "uksc_pre_processing.db")     #处理中的数据库
        destFile = os.path.join(Globals.userCacheUkscDir, "uksc_pre_back.db")        #若前端界面启动，最终处理结束的数据库备份
        readFile = os.path.join(Globals.userCacheUkscDir, "uksc_pre.db")        #前端界面读取使用的数据库

        #reloadCache
        self.reloadCache()


        #通过dbus判断数据是否处于更新中
        try:
            bus = QDBusConnection.sessionBus()
            if not bus.isConnected():
                raise Exception("Could not connect to the D-Bus session.")
        except Exception as e:
            Globals.logError.logger.error("dbus exception: %s" % str(e))
            self.finishDataPreprocessing(False, "0002")
            return

        dbusServer = "com.kylin.softwarecenter.getsearchresults"
        dbusInterface = "com.kylin.getsearchresults"
        dbusPath = "/com/kylin/softwarecenter/getsearchresults"
        reply = False
        try:
            # 使用已连接的 D-Bus 连接创建 QDBusInterface 实例
            iface = QDBusInterface(dbusServer, dbusPath, dbusInterface, bus)
            # 调用 D-Bus 方法并处理返回值和异常
            try:
                message = iface.call("dataUpdateInProgress")
                if message.type() == QDBusMessage.ReplyMessage:
                    # 读取回复消息的内容
                    if(len(message.arguments()) == 1):
                        reply = message.arguments()[0]
                        Globals.logInfo.logger.info("dataUpdateInProgress Method reply:%s" % str(reply))
                else:
                    # 处理错误情况
                    error = message.errorName()
                    Globals.logError.logger.error("get dataUpdateInProgress Error:%s" % str(error))
            except QDBusError as error:
                Globals.logError.logger.error("DBus method call failed: %s" % str(error))
                # 处理错误情况
        except Exception as e:
            Globals.logError.logger.error("Failed to create QDBusInterface: %s" % str(e))
            # 处理创建 QDBusInterface 失败的情况
        if(reply == True):
            if(os.path.exists(destFile) == False or os.path.exists(readFile) == False):
                #没有预处理完的数据库，优先处理安装路径的数据库
                if not os.path.exists(cacheFile):
                    Globals.CONNECT_DB = False
                    if (Globals.debugSwitch):
                        Globals.logError.logger.error("error with db file")
                    return
                else:
                    os.system("cp " + cacheFile + " " + procFile)
            else:
                #已有预处理完的数据库，就等数据更新结束
                while(1):
                    time.sleep(2)
                    try:
                        # 使用已连接的 D-Bus 连接创建 QDBusInterface 实例
                        iface = QDBusInterface(dbusServer, dbusPath, dbusInterface, bus)
                        # 调用 D-Bus 方法并处理返回值和异常
                        try:
                            message = iface.call("dataUpdateInProgress")
                            if message.type() == QDBusMessage.ReplyMessage:
                                # 读取回复消息的内容
                                if (len(message.arguments()) == 1):
                                    reply = message.arguments()[0]
                                    Globals.logInfo.logger.info("dataUpdateInProgress Method reply:%s" % str(reply))
                            else:
                                # 处理错误情况
                                error = message.errorName()
                                Globals.logError.logger.error("get dataUpdateInProgress Error:%s" % str(error))
                        except QDBusError as error:
                            Globals.logError.logger.error("DBus method call failed: %s" % str(error))
                            # 处理错误情况
                    except Exception as e:
                        Globals.logError.logger.error("Failed to create QDBusInterface: %s" % str(e))
                        # 处理创建 QDBusInterface 失败的情况
                    if(reply == False):
                        break


                if not os.path.exists(procFile ):
                    self.copyDbFile(srcFile,cacheFile,procFile)
                else:
                    os.remove(procFile)
                    self.copyDbFile(srcFile, cacheFile, procFile)
        else:
            if not os.path.exists(procFile ):
                self.copyDbFile(srcFile,cacheFile,procFile)
            else:
                os.remove(procFile)
                self.copyDbFile(srcFile, cacheFile, procFile)

        try:
            self.connect = sqlite3.connect(procFile, timeout=30.0, check_same_thread=False)
            self.cursor = self.connect.cursor()
        except Exception as e:
            Globals.CONNECT_DB = False
            Globals.logError.logger.error("Database link failed:  " + str(e))
        if(os.path.exists(Globals.userConfFilePath)):
            try:
                cf = configparser.ConfigParser()
                cf.read(Globals.userConfFilePath)
                self.cpu = cf.get("essential-information","cpu")
                self.arch = cf.get("essential-information","arch")
            except:
                pass
        if(self.cpu == ""):
            self.getCpu()
        if(self.arch == ""):
            self.getArch()
        self.initAptCache()
        self.queryApplicationList()
        self.queryAppTag()
        self.queryAdList()
        self.queryAdLocation()
        Globals.logInfo.logger.info("Initialize data completed")

        #检查商店前端是否启动，判断数据库是否直接拷贝
        if(self.checkProcessIsRunning()):
            #不进行数据库替换，重启前端界面判断是否存在uksc_pre_back.db数据库文件，拷贝后删除
            file1 = QFile(destFile)
            if (file1.exists()):
                file1.remove()
            file2 = QFile(procFile)
            if (file2.copy(destFile)):
                file2.remove()
            pass
        else:
            #进行数据库替换替换成功后删除destFile路径数据库
            file1 = QFile(readFile)
            if(file1.exists()):
                file1.remove()
            file2 = QFile(procFile)
            if(file2.copy(readFile)):
                file2.remove()
            pass
        #需要增加一个判断数据同步结束的信号
        self.finishDataPreprocessing(True,"")


    def reloadCache(self):
        try:
            bus = QDBusConnection.sessionBus()
            if not bus.isConnected():
                raise Exception("Could not connect to the D-Bus session.")
        except Exception as e:
            Globals.logError.logger.error("dbus exception: %s" % str(e))
            self.finishDataPreprocessing(False, "0002")
            return

        packageDbusServer = "com.kylin.softwarecenter.packageInfo"
        packageDbusInterface = "com.kylin.softwarecenter.packageInfo"
        packageDbusPath = "/com/kylin/softwarecenter/packageInfo"
        try:
            # 使用已连接的 D-Bus 连接创建 QDBusInterface 实例
            iface = QDBusInterface(packageDbusServer, packageDbusPath, packageDbusInterface, bus)
            # 调用 D-Bus 方法并处理返回值和异常
            try:
                message = iface.call("reloadAptCache")
                if message.type() == QDBusMessage.ReplyMessage:
                    # 读取回复消息的内容
                    if (len(message.arguments()) == 1):
                        reply = message.arguments()[0]
                        Globals.logInfo.logger.info("reload apt cache Method reply:%s" % str(reply))
                else:
                    # 处理错误情况
                    error = message.errorName()
                    Globals.logError.logger.error("reload apt cache Method Error:%s" % str(error))
            except QDBusError as error:
                Globals.logError.logger.error("reload apt cache Method method call failed: %s" % str(error))
                # 处理错误情况
        except Exception as e:
            Globals.logError.logger.error("Failed to create reload apt cache Method QDBusInterface: %s" % str(e))

    def finishDataPreprocessing(self,res,errorCode):
        Globals.logInfo.logger.info("finish data preprocessing Method reply:%s" % str(res))
        dbusServer = "com.kylin.softwarecenter.getsearchresults"
        dbusInterface = "com.kylin.getsearchresults"
        dbusPath = "/com/kylin/softwarecenter/getsearchresults"
        try:
            bus = QDBusConnection.sessionBus()
            if not bus.isConnected():
                raise Exception("Could not connect to the D-Bus session.")
        except Exception as e:
            Globals.logError.logger.error("dbus exception: %s" % str(e))
            return
        iface = QDBusInterface(dbusServer, dbusPath, dbusInterface, bus)
        # 调用 D-Bus 方法并处理返回值和异常
        try:
            message = iface.call("data_preprocessing_status",res,errorCode)
        except QDBusError as error:
            Globals.logError.logger.error("DBus method call failed: %s" % str(error))

    def checkProcessIsRunning(self):
        #判断前端界面是否正在运行中
        for proc in psutil.process_iter(['name']):
            try:
                if proc.info['name'] == "kylin-software-center":
                    return True
            except (psutil.NoSuchProcess, psutil.AccessDenied, psutil.ZombieProcess):
                pass
        return False

    def copyDbFile(self,srcFile,cacheFile,destFile):
        if not os.path.exists(srcFile):
            if not os.path.exists(cacheFile):
                Globals.CONNECT_DB = False
                if (Globals.debugSwitch):
                    Globals.logError.logger.error("error with db file")
                return
            else:
                os.system("cp " + cacheFile + " " + destFile)
        else:
            # 判断用户路径下的db数据库版本
            if (self.checkDbVersion(srcFile, cacheFile) == 1):
                # 进行数据库更新时间判断
                if (self.checkDbUpdateTime(srcFile, cacheFile) == 1):
                    os.system("cp " + srcFile + " " + destFile)
                else:
                    os.system("cp " + cacheFile + " " + destFile)
                pass
            elif (self.checkDbVersion(srcFile, cacheFile) == -1):
                # 判断数据库版本时数据库链接失败,该模块进程需要重新链接
                pass
            else:
                os.system("cp " + cacheFile + " " + destFile)

    def checkDbVersion(self,dbFile1,dbFile2):
        try:
            connect = sqlite3.connect(dbFile1, timeout=30.0, check_same_thread=False)
            cursor = connect.cursor()
        except Exception as e:
            Globals.CONNECT_DB = False
            Globals.logError.logger.error("Database link failed:  " + str(e))
        try:
            connect1 = sqlite3.connect(dbFile2, timeout=30.0, check_same_thread=False)
            cursor1 = connect1.cursor()
        except Exception as e:
            Globals.CONNECT_DB = False
            Globals.logError.logger.error("Database link failed:  " + str(e))
        res = None
        sql = "select value from dict where key='dbversion'"
        try:
            cursor.execute(sql)
            res = cursor.fetchall()
        except Exception as e:
            Globals.CONNECT_DB = False
            Globals.logError.logger.error("Database link failed:  " + str(e))
            if (str(e) == "database is locked"):
                return -1
        db_version = ""
        if (res != None and res != []):
            db_version = res[0][0]
        res = None
        try:
            cursor1.execute(sql)
            res = cursor1.fetchall()
        except Exception as e:
            Globals.CONNECT_DB = False
            Globals.logError.logger.error("Database link failed:  " + str(e))
            if (str(e) == "database is locked"):
                return -1
        db_version1 = ""
        if (res != None and db_version1 != []):
            db_version1 = res[0][0]
        connect.close()
        connect1.close()
        if (db_version != db_version1):
            return -2
        else:
            return 1

    def checkDbUpdateTime(self,dbFile1,dbFile2):
        try:
            connect = sqlite3.connect(dbFile1, timeout=30.0, check_same_thread=False)
            cursor = connect.cursor()
        except Exception as e:
            Globals.CONNECT_DB = False
            Globals.logError.logger.error("Database link failed:  " + str(e))
        try:
            connect1 = sqlite3.connect(dbFile2, timeout=30.0, check_same_thread=False)
            cursor1 = connect1.cursor()
        except Exception as e:
            Globals.CONNECT_DB = False
            Globals.logError.logger.error("Database link failed:  " + str(e))
        res = None
        sql = "select value from dict where key = 'appinfo_updatetime'"
        try:
            cursor.execute(sql)
            res = cursor.fetchall()
        except Exception as e:
            Globals.CONNECT_DB = False
            Globals.logError.logger.error("Database link failed:  " + str(e))
            if (str(e) == "database is locked"):
                return -1
        dbUpdateTime = ""
        if (res != None and res != []):
            dbUpdateTime = res[0][0]
        res = None
        try:
            cursor1.execute(sql)
            res = cursor1.fetchall()
        except Exception as e:
            Globals.CONNECT_DB = False
            Globals.logError.logger.error("Database link failed:  " + str(e))
            if (str(e) == "database is locked"):
                return -1
        dbUpdateTime1 = ""
        if (res != None and dbUpdateTime1 != []):
            dbUpdateTime1 = res[0][0]
        connect.close()
        connect1.close()
        if (dbUpdateTime != "" and dbUpdateTime1 != ""):
            format_pattern = "%Y-%m-%d %H:%M:%S"
            difference = (datetime.datetime.strptime(str(dbUpdateTime1),
                                                     format_pattern) - datetime.datetime.strptime(
                str(dbUpdateTime), format_pattern))
            if (difference.days <= 0):
                return 1
            else:
                return -1
        else:
            return -1

    def getCpu(self):
        cpuModel = ""
        process = QProcess()
        cmd = "cat /proc/cpuinfo"
        process.start(cmd)
        process.waitForFinished(-1)
        arr = process.readAll()
        readText = arr.data().decode().split("\n")
        for text in readText:
            if("Hardware" in text and len(text.split(":")) >= 2):
                cpuModel = text.split(":")[1]
            elif("model name" in text and len(text.split(":")) >= 2):
                cpuModel = text.split(":")[1]

        if (cpuModel.replace("\n", "").replace(" ", "").lower() != ""):
            self.cpu = cpuModel.replace("\n", "").replace(" ", "").lower()
            if(len(self.cpu) != 0):
                if("kirin990" in self.cpu or ("kirin" in self.cpu and "990" in self.cpu)):
                    self.cpu = "kirin990"
                elif("huaweikirin9006C" in self.cpu or ("kirin" in self.cpu and "9006c" in self.cpu)):
                    self.cpu = "kirin9006c"
                elif("Intel" in self.cpu):
                    self.cpu = "Intel"
                elif("AMD" in self.cpu):
                    self.cpu = "AMD"
                elif("Hygon" in self.cpu):
                    self.cpu = "Hygon"
                elif("ZHAOXIN" in self.cpu):
                    self.cpu = "ZHAOXIN"
                elif(("FT2000A" in self.cpu and "4-Core" in self.cpu) or "FT-2000" in self.cpu):
                    self.cpu = "FT2000/4"
                elif("loongson" in self.cpu and "3a4000" in self.cpu):
                    self.cpu = "loongson3A R4(Loongson3A4000)"
                else:
                    if("D2000" in self.cpu and "Phytium" in self.cpu):
                        self.cpu = "D2000"
                    else:
                        if(len(self.cpu.split(",")) > 1):
                            self.cpu = self.cpu.split(",")[1].replace(" ", "").replace("\n", "")
        pass

    def getArch(self):
        process = QProcess()
        cmd = "dpkg --print-architecture"
        process.start(cmd)
        process.waitForFinished(-1)
        arr = process.readAll()
        self.arch = arr.data().decode().replace("\n","")


    #init apt cache
    def initAptCache(self):
        try:
            self.aptCache = apt.Cache()
            # self.ca.open()
        except:
            self.aptCache = None

    #chack package
    def get_package_by_name(self,pkgname):
        if not pkgname:
            return None
        if self.aptCache is None:
            return None
        package = None
        try:
            package = self.aptCache[pkgname]
        except:
            package = None
        if package is not None:
            try:
                if package.candidate is None:
                    package = None
            except:
                package = None
        return package

    #检测定向上架应用
    def checkCpuModel(self,cpuModel,noCpuModel):
        hwmonDir = QDir("/sys/class/hwmon")
        readName = ""
        checkCpu = self.cpu
        archIn = True
        inCpuModel = True
        inNoCpuModel = False
        if(hwmonDir.exists()):
            fileList = hwmonDir.entryInfoList()
            for fileInfo in fileList:
                if(QFile.exists(fileInfo.absoluteFilePath() + "/name")):
                    file = QFile(fileInfo.absoluteFilePath() + "/name")
                    file.open(QIODevice.ReadOnly | QIODevice.Text)
                    data = file.readAll()
                    file.close()
                    readline = data.data().decode()
                    if ("huawei_qs" in readline):
                        checkCpu = "huawei_qs"
        if(cpuModel != "" and cpuModel != None):
            archIn = False
            inCpuModel = False
            for getCpuModel in cpuModel.split(";"):
                if(len(getCpuModel.split(":")) == 2 and (self.arch.lower() == getCpuModel.split(":")[0].lower() or getCpuModel.split(":")[0].lower() == "all" )):
                    archIn = True
                    if(checkCpu.lower() in getCpuModel.split(":")[1].lower().split(",")):
                        inCpuModel = True
        #说明定向上架只在某个架构或cpu显示，不包括本机
        if(archIn == False or inCpuModel == False):
            return False
        if (noCpuModel != "" and noCpuModel != None):
            archIn = False
            inNoCpuModel = False
            for getCpuModel in noCpuModel.split(";"):
                if (len(getCpuModel.split(":")) == 2 and (self.arch.lower() == getCpuModel.split(":")[0].lower() or getCpuModel.split(":")[0].lower() == "all")):
                    archIn = True
                    if (checkCpu.lower() in getCpuModel.split(":")[1].lower().split(",")):
                        inNoCpuModel = True

        if(((noCpuModel == "" or noCpuModel == None) and archIn == True and inCpuModel == True) or (noCpuModel != "" and noCpuModel != None and (archIn == False or inNoCpuModel == False))):
            return True
        return False


    # 预处理application表格
    def queryApplicationList(self):
        Globals.logInfo.logger.info("get application table")
        androidAppList = self.queryAndroidAppList()
        res = None
        sql = "select id,app_name,b.tagId,cpu_model,no_cpu_model\
            from application a INNER join (select appId,group_concat(distinct tagId) as tagId from app_tag where tagStatus=0 and deleted=0 group by appId) b\
            on a.id = b.appId\
            order by download_total desc;"
        try:
            self.cursor.execute(sql)
            res = self.cursor.fetchall()
        except Exception as e:
            Globals.CONNECT_DB = False
            Globals.logError.logger.error("select application list from application failed:  " + str(e))
            if (str(e) == "database is locked"):
                return -1
        if(res != None and res != []):
            for item in res:
                if(len(item) == 5):
                    appId = str(item[0])
                    pkgname = str(item[1])
                    tagId = str(item[2])
                    cpuModel = item[3]
                    noCpuModel = item[4]
                    if("100" in tagId.split(",")):
                        continue
                    package = self.get_package_by_name(pkgname)
                    #标签中包含移动应应
                    if(Globals.androidTagId in tagId.split(",")):
                        if(androidAppList != [] and appId not in androidAppList):
                            sql = "delete from application where id=" + str(appId)
                            try:
                                lock.acquire(True)
                                self.cursor.execute(sql)
                                self.connect.commit()
                            except Exception as e:
                                Globals.CONNECT_DB = False
                                Globals.logError.logger.error("delete application info from application table failed:  " + str(e))
                                if (str(e) == "database is locked"):

                                    return -1
                            finally:
                                lock.release()
                        pass
                    #缺开明包的判断处理
                    else:
                        #若获取到的package为空则表示源里面没有
                        if package is None:
                            #从数据库删除
                            sql = "delete from application where id="+str(appId)
                            try:
                                lock.acquire(True)
                                self.cursor.execute(sql)
                                self.connect.commit()
                            except Exception as e:
                                Globals.CONNECT_DB = False
                                Globals.logError.logger.error("delete application info from application table failed:  " + str(e))
                                if (str(e) == "database is locked"):
                                    return -1
                            finally:
                                lock.release()
                            continue
                        else:
                            # 检查定向上架字段
                            if(self.checkCpuModel(cpuModel,noCpuModel) == False):
                                # 从数据库删除
                                sql = "delete from application where id=" + str(appId)
                                try:
                                    lock.acquire(True)
                                    self.cursor.execute(sql)
                                    self.connect.commit()
                                except Exception as e:
                                    Globals.CONNECT_DB = False
                                    Globals.logError.logger.error("delete application info from application table failed:  " + str(e))
                                    if (str(e) == "database is locked"):
                                        return -1
                                finally:
                                    lock.release()
                                continue
                            else:
                                packageStatus = 0
                                size=aptDescription=version=aptSummary= ""

                                if (package.is_installed and package.candidate.installed_size != 0):
                                    size = package.candidate.installed_size
                                else:
                                    size = package.candidate.size
                                version = package.candidate.version
                                aptDescription = package.candidate.description
                                aptSummary = package.candidate.summary
                                #包存在则检测包的安装状态
                                if(package.is_upgradable and package.is_installed):
                                    packageStatus = 2
                                elif(package.is_installed and package.is_upgradable == False):
                                    packageStatus = 1
                                sql = "update application set packageStatus=?,size=?,version=?,aptDescription=?,aptSummary=? where id=? "
                                try:
                                    lock.acquire(True)
                                    self.cursor.execute(sql, (packageStatus,size,version,aptDescription,aptSummary, appId))
                                    self.connect.commit()
                                except Exception as e:
                                    Globals.logError.logger.error("update packageStatus msg: %s" % str(e))
                                finally:
                                    lock.release()

                            pass
        pass


    def queryAndroidAppList(self):
        res = None
        sql = "select appid from kydroid_app_list"
        try:
            self.cursor.execute(sql)
            res = self.cursor.fetchall()
        except Exception as e:
            Globals.CONNECT_DB = False
            Globals.logError.logger.error("select from kydroid_app_list failed:  " + str(e))
            if (str(e) == "database is locked"):
                return -1

        androidAppList = []
        if(res != None and res !=[]):
            for item in res:
                if(len(item) == 1):
                    androidAppList.append(item[0])
        return androidAppList

    # 预处理app_tag表格
    def queryAppTag(self):
        res = None
        sql = "delete from app_tag where appId not in (select id from application) or (deleted != 0 or tagStatus != 0)"
        try:
            lock.acquire(True)
            self.cursor.execute(sql)
            self.connect.commit()
        except Exception as e:
            Globals.CONNECT_DB = False
            Globals.logError.logger.error("delete from app_tag failed:  " + str(e))
            if (str(e) == "database is locked"):
                return -1
        finally:
            lock.release()

    #预处理广告模块
    def queryAdList(self):
        res = None
        sql = "select id,softwareId from ad_list"
        try:
            self.cursor.execute(sql)
            res = self.cursor.fetchall()
        except Exception as e:
            Globals.CONNECT_DB = False
            Globals.logError.logger.error("select from ad_list failed:  " + str(e))
            if (str(e) == "database is locked"):
                return -1

        if (res != None and res != []):
            for item in res:
                if (len(item) >= 2):
                    adId = item[0]
                    softwareId = str(item[1])
                    #带逗号的为专题数据
                    if(len(softwareId.split(",")) == 1 or softwareId == "" or softwareId == None):
                        sql = "delete from ad_list where id="+str(adId) +" and (softwareId not in (select id from application))"
                        try:
                            lock.acquire(True)
                            self.cursor.execute(sql)
                            self.connect.commit()
                        except Exception as e:
                            Globals.CONNECT_DB = False
                            Globals.logError.logger.error("delete from ad_list failed:  " + str(e))
                            if (str(e) == "database is locked"):
                                return -1
                        finally:
                            lock.release()
        pass

    def queryAdLocation(self):
        #删除不会显示的广告位
        sql = "delete from ad_locations where id not in (select locationId from ad_list) and template != 0"
        try:
            lock.acquire(True)
            self.cursor.execute(sql)
            self.connect.commit()
        except Exception as e:
            Globals.CONNECT_DB = False
            Globals.logError.logger.error("delete from ad_locations failed:  " + str(e))
            if (str(e) == "database is locked"):
                return -1
        finally:
            lock.release()

        #删除不存在的广告位的国际化数据
        sql = "delete from ad_locations_internationalization where locationId not in (select id from ad_locations)"
        try:
            lock.acquire(True)
            self.cursor.execute(sql)
            self.connect.commit()
        except Exception as e:
            Globals.CONNECT_DB = False
            Globals.logError.logger.error("delete from ad_locations_internationalization failed:  " + str(e))
            if (str(e) == "database is locked"):
                return -1
        finally:
            lock.release()

    #预处理搜索推荐应用列表
    def querySearchHotApp(self):
        sql = "delete from search_hot_app where softwareId not in (select id from application)"
        try:
            lock.acquire(True)
            self.cursor.execute(sql)
            self.connect.commit()
        except Exception as e:
            Globals.CONNECT_DB = False
            Globals.logError.logger.error("search hot app list failed:  " + str(e))
            if (str(e) == "database is locked"):
                return -1
        finally:
            lock.release()


